//********************************************************************
//*                                                                  *
//*            INSERT A JOBCARD ABOVE THIS COMMENT BOX               *
//*                                                                  *
//********************************************************************
//*
//********************************************************************
//*                                                                  *
//* Member Name:  MVSPATCH                                           *
//*                                                                  *
//* Last Revised: 06/17/2015                                         *
//*                                                                  *
//* Description:  This job;                                          *
//*               is used to install any z/OS Precisely Software     *
//*               Open Systems product patch downloaded from the     *
//*               Precisely Software Support Site                    *
//*               (Special Request Download Area - SRD).             *
//*                                                                  *
//*               This job installs z/OS patches to a                *
//*               z/OS-compatible mainframe.                         *
//*                                                                  *
//*               Certain pre-requisite knowledge is required to     *
//*               properly install the patch.                        *
//*                                                                  *
//*               Please review the install instructions prior       *
//*               to using this JCL.                                 *
//*                                                                  *
//******  A T T E N T I O N  **************  A T T E N T I O N  ******
//*                                                                  *
//*    PRIOR TO UTILIZING THIS JOB YOU MUST UNZIP THE FILE THAT WAS  *
//*    DOWNLOADED FROM THE INTERNET SITE. THE FILE IS A              *
//*    SELF-EXTRACTING ZIP FILE.                                     *
//*                                                                  *
//*    YOU SHOULD NOTE THAT 'yourhlq2.ppp.*LIB' ARE TEST OBJECT/LOAD *
//*    LIBRARIES AND WILL CONTAIN ONLY OBJECT MODULES THAT WERE      *
//*    WITH THIS 'PATCH'.                                            *
//*                                                                  *
//*    IF YOU UTILIZE A DIFFERENT BATCH FILE TRANSFER MECHANISM, THEN*
//*    REPLACE THE 'FTPFRNET' STEP WITH YOUR FILE-TRANSFER MECHANISM.*
//*                                                                  *
//*    IF YOU DO NOT HAVE A "BATCH" FILE-TRANSFER MECHANISM, BUT YOU *
//*    HAVE AN INTERACTIVE FILE-TRANSFER MECHANISM, SIMPLY UPLOAD THE*
//*    FILES THAT ARE IN THE FTP "GET" COMMAND TO THE MAINFRAME.     *
//*                                                                  *
//*    USE THE FOLLOWING SETTINGS IN YOUR FILE-TRANSFER MECHANISM:   *
//*    - ASIS    - BINARY TRANSFER (THE FILES ARE IN EBCDIC FORMAT)  *
//*    - NO CRLF - NO CARRIAGE RETURN/LINE FEED                      *
//*    - RECFM   - FB (FIXED-BLOCK)                                  *
//*    - BLKSIZE - 1600                                              *
//*    - LRECL   - 80                                                *
//*                                                                  *
//*    NOTE: THIS PROCESS REQUIRES THAT THE MAINFRAME HAVE ACCESS    *
//*    TO YOUR NETWORK IN SOME FASHION. PLEASE CONTACT YOUR NETWORK  *
//*    ADMINISTRATOR IF YOU ARE NOT SURE, OR CANNOT ACCESS THE       *
//*    NETWORK FROM THE MAINFRAME.                                   *
//*                                                                  *
//*******  A T T E N T I O N  *************  A T T E N T I O N  ******
//*                                                                  *
//*      CLEANUP1: DELETES OLD IDS AND FTP DATASETS                  *
//*      PREALLOC: ALLOCATES DATASETS TO BE USED IN FTP              *
//*      FTPFRNET: RUNS THE FILE TRANSFER PROCESS                    *
//*      RECEIVE:  RUNS IKJEFT01 TO RELOAD LIBRARIES                 *
//*      CLEANUP2: DELETES OLD INTERNET DELIVERY DATASETS            *
//*                                                                  *
//*      EXPECTED RETURN CODES;                                      *
//*      - CLEANUP1: IDCAMS   - 0                                    *
//*      - PREALLOC: IEFBR14  - 0                                    *
//*      - FTPFRNET: FTP      - 0                                    *
//*      - RECEIVE:  IKJEFT01 - 0                                    *
//*      - CLEANUP2: IDCAMS   - 0                                    *
//*                                                                  *
//*                                                                  *
//* VARIABLES:    THE FOLLOWING LOWER-CASE VARIABLES MUST BE CHANGED *
//*               IN ORDER TO RUN THIS JOB:                          *
//*                                                                  *
//*              ** NOTE **                                          *
//*              PLEASE MAKE SURE TO SET "CAPS ON" PRIOR TO EDITING. *
//*              +-------------------+------------------------------+*
//*              |VARIABLE;          | REPLACE WITH;                |*
//*              +-------------------+------------------------------+*
//*              |ppp                | The product code. Which is   |*
//*              |                   | the same as the first three  |*
//*              |                   | characters of the SRD file   |*
//*              |                   | name.                        |*
//*              +-------------------+------------------------------+*
//*              |prdct              | The product acronym in use   |*
//*              |                   | at your site. eg "CODE1P"    |*
//*              |                   |                  "MAILSP"    |*
//*              +-------------------+------------------------------+*
//*              |yourhlq1           | The high level qualifier to  |*
//*              |                   | be used for the output of    |*
//*              |                   | the FTP step.                |*
//*              +-------------------+------------------------------+*
//*              |yourhlq2           | The high level qualifier to  |*
//*              |                   | be used for the output of    |*
//*              |                   | the various load processes.  |*
//*              +-------------------+------------------------------+*
//*              |volum1             | DASD pack volser where the   |*
//*              |                   | datasets will be allocated.  |*
//*              +-------------------+------------------------------+*
//*              |volum2             | DASD pack volser where the   |*
//*              |                   | object and load libraries    |*
//*              |                   | will be allocated.           |*
//*              +-------------------+------------------------------+*
//*              |ipaddress          | The IP address for the LAN.  |*
//*              +-------------------+------------------------------+*
//*              |tcpip.loadlib                                     |*
//*              |                   +------------------------------+*
//*              |                   | The load library where "FTP" |*
//*              |                   | resides.                     |*
//*              +-------------------+------------------------------+*
//*              |tcpip.supportlib                                  |*
//*              |                   +------------------------------+*
//*              |                   | The load library where FTP   |*
//*              |                   | support routines reside.     |*
//*              +-------------------+------------------------------+*
//*              |tcpip.data                                        |*
//*              |                   +------------------------------+*
//*              |                   | The dataset that is used to  |*
//*              |                   | specify configuration        |*
//*              |                   | information required by      |*
//*              |                   | TCP/IP client programs.      |*
//*              +-------------------+------------------------------+*
//*              |tcpip.diskparms                                   |*
//*              |                   +------------------------------+*
//*              |                   | The file that is used        |*
//*              |                   | to specify default file      |*
//*              |                   | and disk parameters used     |*
//*              |                   | by the FTP server.           |*
//*              +-------------------+------------------------------+*
//*              |hostname           | The host name for the LAN.   |*
//*              +-------------------+------------------------------+*
//*              |landirectory1                                     |*
//*              |                   +------------------------------+*
//*              |                   | The directory structure where|*
//*              |                   | the files that were          |*
//*              |                   | downloaded from the PB       |*
//*              |                   | INTERNET site are stored.    |*
//*              +-------------------+------------------------------+*
//*                                                                  *
//*******  A T T E N T I O N  *************  A T T E N T I O N  ******
//*                                                                  *
//* Before running this jcl, please delete any references to files   *
//* not included in the installation folder. For example, if the     *
//* installation folder only contains a .LOAD file, delete any       *
//* references to .LOAD.PDSE and .LOADLIB.PDSE files.                *
//*                                                                  * 
//********************************************************************
//*
//*
//CLEANUP1 EXEC  PGM=IDCAMS
//SYSPRINT DD   SYSOUT=*
//SYSIN    DD   *

 DELETE  yourhlq1.ppp.OBJ             PURGE
 DELETE  yourhlq1.ppp.LOAD            PURGE
 DELETE  yourhlq1.ppp.LOAD.PDSE       PURGE

 DELETE  yourhlq2.prdct.OBJLIB        PURGE
 DELETE  yourhlq2.prdct.LOADLIB       PURGE
 DELETE  yourhlq2.prdct.LOADLIB.PDSE  PURGE
 
 SET MAXCC=0

/*
//*
//PREALLOC EXEC PGM=IEFBR14
//BIRTH01  DD   DSN=yourhlq1.ppp.OBJ,DISP=(,CATLG,DELETE),
//         UNIT=SYSDA,VOL=SER=volum1,
//         DCB=(RECFM=FB,LRECL=80,BLKSIZE=1600,DSORG=PS),
//         SPACE=(TRK,(300,5))
//BIRTH02  DD   DSN=yourhlq1.ppp.LOAD,DISP=(,CATLG,DELETE),
//         UNIT=SYSDA,VOL=SER=volum1,
//         DCB=(RECFM=FB,LRECL=80,BLKSIZE=1600,DSORG=PS),
//         SPACE=(TRK,(300,5))
//BIRTH03  DD   DSN=yourhlq1.ppp.LOAD.PDSE,DISP=(,CATLG,DELETE),
//         UNIT=SYSDA,VOL=SER=volum1,
//         DCB=(RECFM=FB,LRECL=80,BLKSIZE=1600,DSORG=PS),
//         SPACE=(TRK,(300,5))
//*
//FTPFRNET EXEC PGM=FTP,REGION=3M,PARM='ipaddress (TIMEOUT 20'
//STEPLIB  DD   DSN=tcpip.loadlib,DISP=SHR
//         DD   DSN=tcpip.supportlib,DISP=SHR
//SYSTCPD  DD   DSN=tcpip.data,DISP=SHR
//SYSFTPD  DD   DSN=tcpip.diskparms,DISP=SHR
//SYSPRINT DD   SYSOUT=*
//OUTPUT   DD   SYSOUT=*
//SYSMDUMP DD   SYSOUT=*
//INPUT    DD   *
 ANONYMOUS yourhlq1@hostname
 CD landirectory1
 LCD 'yourhlq1'
 BINARY
 DIR
 GET pppCMVS.OBJ           'yourhlq1.ppp.OBJ'          (REPLACE
 GET pppCMVS.LOAD          'yourhlq1.ppp.LOAD'         (REPLACE
 GET pppCMVS.LOAD.PDSE     'yourhlq1.ppp.LOAD.PDSE'    (REPLACE
 
 LPWD
 QUIT
//*
//RECEIVE  EXEC PGM=IKJEFT01,REGION=1500K
//SYSTSPRT DD   SYSOUT=*
//SYSTSIN  DD   *

RECEIVE INDSN('yourhlq1.ppp.OBJ')
        DATASET('yourhlq2.prdct.OBJLIB') VOL(volum2)

RECEIVE INDSN('yourhlq1.ppp.LOAD')
        DATASET('yourhlq2.prdct.LOADLIB') VOL(volum2)

RECEIVE INDSN('yourhlq1.ppp.LOAD.PDSE')
        DATASET('yourhlq2.prdct.LOADLIB.PDSE') VOL(volum2)

/*
//CLEANUP2 EXEC  PGM=IDCAMS
//SYSPRINT DD   SYSOUT=*
//SYSIN    DD   *

 DELETE  yourhlq1.ppp.OBJ        PURGE
 DELETE  yourhlq1.ppp.LOAD       PURGE
 DELETE  yourhlq1.ppp.LOAD.PDSE  PURGE
 
 SET MAXCC=0

/*
//*
//* See IDSINSTL in your original INSTALL library to obtain the JCL
//*     required to load other datasets and libraries, which may be
//*     present with this product update.
//
